from flask import Blueprint
from .renderer import render_field, csrf_setup
from .filters import (
    timesince,
    local_date,
    percent_escape,
    local_date_time,
    get_autoincluded_assets
)
class Boilerplate(object):

    def __init__(self, app=None, **kwargs):
        self.app = app

        if app is not None:
            self._state = self.init_app(app, **kwargs)

    def init_app(self, app):
        bp = Blueprint(
            'boilerplate',
            __name__,
            template_folder='templates',
            url_prefix='/bp'
        )

        app.register_blueprint(bp)

        app.jinja_env.globals['csrf_setup'] = csrf_setup
        app.jinja_env.globals['render_field'] = render_field
        app.jinja_env.globals['html_assets'] = get_autoincluded_assets(app)()
        app.jinja_env.filters['local_date'] = local_date
        app.jinja_env.filters['local_date_time'] = local_date_time
        app.jinja_env.filters['percent_escape'] = percent_escape
        app.jinja_env.filters['time_since'] = timesince



import os
from setuptools import setup

readme_path = os.path.join(os.path.dirname(
  os.path.abspath(__file__)),
  'README.md',
)
long_description = open(readme_path).read()

setup(
  name='flask-boilerplate-utils',
  version='0.1.0',
  packages=['flask_boilerplate_utils'],
  author="Nick Whyte",
  author_email='nick@nickwhyte.com',
  description="Additional functionality with easy upgrading for the flask-boilerplate.",
  long_description=long_description,
  url='https://github.com/nickw444/flask-phantom-emoji',
  include_package_data=True,
  zip_safe=False,
  install_requires=[
    "Flask",
  ],
)
